Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(145)

Unified Diff: ios/web_view/internal/criwv_web_main_parts.h

Issue 2710683007: Rename CRIWVBrowserState to CWVBrowserState. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/web_view/internal/criwv_web_client.mm ('k') | ios/web_view/internal/criwv_web_main_parts.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web_view/internal/criwv_web_main_parts.h
diff --git a/ios/web_view/internal/criwv_web_main_parts.h b/ios/web_view/internal/criwv_web_main_parts.h
index 927de68ae0ae8f1b9c718555c11aa4bb4d373cc9..d3a56d821b8bea55955ba40bb5edc42e5afc1170 100644
--- a/ios/web_view/internal/criwv_web_main_parts.h
+++ b/ios/web_view/internal/criwv_web_main_parts.h
@@ -12,7 +12,7 @@
@protocol CWVDelegate;
namespace ios_web_view {
-class CRIWVBrowserState;
+class CWVBrowserState;
// CWV-specific implementation of WebMainParts.
class CRIWVWebMainParts : public web::WebMainParts {
@@ -23,11 +23,11 @@ class CRIWVWebMainParts : public web::WebMainParts {
// WebMainParts implementation.
void PreMainMessageLoopRun() override;
- // Returns the CRIWVBrowserState for this embedder.
- CRIWVBrowserState* browser_state() const { return browser_state_.get(); }
+ // Returns the CWVBrowserState for this embedder.
+ CWVBrowserState* browser_state() const { return browser_state_.get(); }
- // Returns the off the record CRIWVBrowserState for this embedder.
- CRIWVBrowserState* off_the_record_browser_state() const {
+ // Returns the off the record CWVBrowserState for this embedder.
+ CWVBrowserState* off_the_record_browser_state() const {
return off_the_record_browser_state_.get();
}
@@ -36,10 +36,10 @@ class CRIWVWebMainParts : public web::WebMainParts {
__weak id<CWVDelegate> delegate_;
// The BrowserState for this embedder.
- std::unique_ptr<CRIWVBrowserState> browser_state_;
+ std::unique_ptr<CWVBrowserState> browser_state_;
// The BrowserState for this embedder.
- std::unique_ptr<CRIWVBrowserState> off_the_record_browser_state_;
+ std::unique_ptr<CWVBrowserState> off_the_record_browser_state_;
};
} // namespace ios_web_view
« no previous file with comments | « ios/web_view/internal/criwv_web_client.mm ('k') | ios/web_view/internal/criwv_web_main_parts.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698